##  What You'll Achieve
  * Build foundational knowledge: Learn the essential concepts of SAP LeanIX to support your future architecture work.
  * Gain practical experience: Use the core features and capabilities of SAP LeanIX to get hands-on practice.
  * Accelerate time to value: Complete your first application portfolio assessment to establish transparency and governance over your as-is landscape. By importing initial data into your workspace and setting up data governance processes, you achieve first tangible results that you can share with stakeholders to demonstrate the value of SAP LeanIX.
